@@ -106,6 +106,7 @@ print.MixtCompLearn <- function(x, nVarMaxToPrint = 5, nClass = NULL, ...)
 #' @param nVarMaxToPlot number of variables to display
 #' @param nClass number of classes of the model to plot
 #' @param pkg "ggplot2" or "plotly". Package used to plot
+#' @param plotData "CI" or "Boxplot". If "CI", uses \link{plotDataCI} function. If "Boxplot", uses \link{plotDataBoxplot}
 #' @param ... extra parameter for \link{plotDataCI}
 #' 
 #' @examples 
@@ -115,7 +116,7 @@ print.MixtCompLearn <- function(x, nVarMaxToPrint = 5, nClass = NULL, ...)
 #' resLearn <- mixtCompLearn(iris[, -5], nClass = 2:4)
 #' 
 #' plot(resLearn)
-#' plot(resLearn, nClass = 3)
+#' plot(resLearn, nClass = 3, plotData = "Boxplot")
 #' 
 #' @method plot MixtCompLearn
 #' 
@@ -123,7 +124,7 @@ print.MixtCompLearn <- function(x, nVarMaxToPrint = 5, nClass = NULL, ...)
 #' @family plot
 #' @author Quentin Grimonprez
 #' @export
-plot.MixtCompLearn <- function(x, nVarMaxToPlot = 3, nClass = NULL, pkg = c("ggplot2", "plotly"), ...)
+plot.MixtCompLearn <- function(x, nVarMaxToPlot = 3, nClass = NULL, pkg = c("ggplot2", "plotly"), plotData = c("CI", "Boxplot"), ...)
 {
   pkg = match.arg(pkg)
   
@@ -135,9 +136,9 @@ plot.MixtCompLearn <- function(x, nVarMaxToPlot = 3, nClass = NULL, pkg = c("ggp
     
     if(!is.null(nClass) && (nClass[1] %in% x$nClass))
     {
-      p2 <- plot(x$res[[which(x$nClass == nClass[1])]], nVarMaxToPlot = nVarMaxToPlot, nClass = nClass, pkg = pkg, ...)
+      p2 <- plot(x$res[[which(x$nClass == nClass[1])]], nVarMaxToPlot = nVarMaxToPlot, nClass = nClass, pkg = pkg, plotData = plotData, ...)
     }else{
-      p2 <- plot(x$res[[which(x$nClass == x$algo$nClass)]], nVarMaxToPlot = nVarMaxToPlot, nClass = nClass, pkg = pkg, ...)
+      p2 <- plot(x$res[[which(x$nClass == x$algo$nClass)]], nVarMaxToPlot = nVarMaxToPlot, nClass = nClass, pkg = pkg, plotData = plotData, ...)
     }
     
     p = c(p, p2)
