@@ -278,6 +278,7 @@ mixtCompLearn <- function(data, model = NULL, algo = createAlgo(), nClass, crite
   }
   
   performHier <- performHierarchical(hierarchicalMode, mode, model)
+  nClass = sort(unique(nClass))
   
   ## run MixtComp
   if(performHier)
@@ -332,7 +333,7 @@ mixtCompPredict <- function(data, model = NULL, algo = resLearn$algo, resLearn,
     resPredict <- rmcMultiRun(algo, dataList, model, resLearn, nRun, nCore, verbose)
   
   if(!is.null(resPredict$warnLog))
-    warning(paste0("MixtComp failed with the following error: ", resPredict$warnLog))
+    warning(paste0("MixtComp failed with the following error:\n", resPredict$warnLog))
   else{
     resPredict$algo$basicMode = resLearn$algo$basicMode
     
@@ -374,8 +375,6 @@ classicLearn <- function(data, model, algo, nClass, criterion, nRun, nCore, verb
   
   algo = RMixtCompUtilities:::completeAlgo(algo)
   
-  nClass = unique(nClass)
-  
   indCrit <- ifelse(criterion == "BIC", 1, 2)
   
   if(verbose)
@@ -398,7 +397,7 @@ classicLearn <- function(data, model, algo, nClass, criterion, nRun, nCore, verb
     
     class(resLearn[[i]]) = "MixtComp"
     if(!is.null(resLearn[[i]]$warnLog))
-      warning(paste0("For k=", nClass[i], ", MixtComp failed with the following error: ", resLearn[[i]]$warnLog))
+      warning(paste0("For k=", nClass[i], ", MixtComp failed with the following error:\n", resLearn[[i]]$warnLog))
     else{
       if(verbose)
         cat(paste0("Run completed in ", round((t2-t1)[3], 3), "s\n"))
