@@ -52,17 +52,9 @@ plotCrit <- function(output, pkg = c("ggplot2", "plotly"), ...)
 # @author Quentin Grimonprez
 plotlyCrit <- function(crit, nClass, ...)
 {
-  if(length(nClass) == 1)
-  {
-    p <- plot_ly(x = nClass, y = crit[1,], type = "scatter", mode = "markers", symbol = 1, name = "BIC", size = 2, ...) %>%
-      add_trace(x = nClass, y = crit[2,], name = "ICL", symbol = 2, size = 2)%>%
-      layout(title = "Criterion", showlegend = TRUE, xaxis = list(title = "Number of classes"), yaxis = list(title = "Value"))
-  }else{
-    p <- plot_ly(x = nClass, y = crit[1,], type = "scatter", mode = "lines", name = "BIC", ...) %>%
-      add_trace(x = nClass, y = crit[2,], name = "ICL")%>%
-      layout(title = "Criterion", showlegend = TRUE, xaxis = list(title = "Number of classes"), yaxis = list(title = "Value"))
-  }
-  
+  p <- plot_ly(x = nClass, y = crit[1,], type = "scatter", mode = "lines+markers", name = "BIC", ...) %>%
+    add_trace(x = nClass, y = crit[2,], name = "ICL")%>%
+    layout(title = "Criterion", showlegend = TRUE, xaxis = list(title = "Number of classes", range = range(nClass)), yaxis = list(title = "Value"))
   
   p
 }
@@ -73,11 +65,9 @@ ggplotCrit <- function(crit, nClass)
   df = data.frame(class = nClass, value = c(crit[1,], crit[2,]), Criterion = rep(c("BIC", "ICL"), each = length(nClass)))
   
   p <- ggplot(data = df, aes_string(x = "class", y = "value", col = "Criterion")) +
-    labs(title = "Criterion", x = "Number of classes", y = "value")
-  
-  if(length(nClass) == 1)
-    p = p + geom_point(aes_string(shape = "Criterion"), size = 3)
-  else
-    p = p + geom_line()
+    labs(title = "Criterion", x = "Number of classes", y = "value") + 
+    geom_line() + 
+    geom_point(aes_string(shape = "Criterion"), size = 2) + 
+    scale_x_continuous(breaks = pretty_breaks()(nClass))
   p
 }
